==> openflowplugin-extension-nicira-0.5.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/NxActionRegMoveGrouping.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.move.grouping.NxRegMove;
import org.opendaylight.yangtools.yang.common.QName;

/**
 * <p>This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * grouping nx-action-reg-move-grouping {
 *     container nx-reg-move {
 *         container src {
 *             choice src-choice {
 *                 case src-nx-arp-sha-case {
 *                     leaf nx-arp-sha {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-arp-tha-case {
 *                     leaf nx-arp-tha {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-encap-eth-dst-case {
 *                     leaf nx-encap-eth-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-encap-eth-src-case {
 *                     leaf nx-encap-eth-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-ipv6-dst-case {
 *                     leaf nx-ipv6-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-ipv6-src-case {
 *                     leaf nx-ipv6-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-nsh-mdtype-case {
 *                     leaf nx-nsh-mdtype {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-nsh-np-case {
 *                     leaf nx-nsh-np {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-nshc-1-case {
 *                     leaf nx-nshc-1-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-nshc-2-case {
 *                     leaf nx-nshc-2-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-nshc-3-case {
 *                     leaf nx-nshc-3-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-nshc-4-case {
 *                     leaf nx-nshc-4-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-nsi-case {
 *                     leaf nx-nsi-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-nsp-case {
 *                     leaf nx-nsp-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-of-in-port-case {
 *                     leaf of-in-port {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-of-metadata-case {
 *                     leaf of-metadata {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-of-mpls-label-case {
 *                     leaf of-mpls-label {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-reg-case {
 *                     leaf nx-reg {
 *                         type identityref;
 *                     }
 *                 }
 *                 case src-nx-tun-gpe-np-case {
 *                     leaf nx-tun-gpe-np {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-tun-id-case {
 *                     leaf nx-tun-id {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-tun-ipv4-dst-case {
 *                     leaf nx-tun-ipv4-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-tun-ipv4-src-case {
 *                     leaf nx-tun-ipv4-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-of-arp-op-case {
 *                     leaf of-arp-op {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-of-arp-spa-case {
 *                     leaf of-arp-spa {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-of-arp-tpa-case {
 *                     leaf of-arp-tpa {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-of-eth-dst-case {
 *                     leaf of-eth-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-of-eth-src-case {
 *                     leaf of-eth-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-of-eth-type-case {
 *                     leaf of-eth-type {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-of-ip-dst-case {
 *                     leaf of-ip-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-of-ip-src-case {
 *                     leaf of-ip-src {
 *                         type empty;
 *                     }
 *                 }
 *             }
 *             leaf start {
 *                 type uint16;
 *             }
 *             leaf end {
 *                 type uint16;
 *             }
 *             uses src-choice-grouping;
 *             uses range-grouping;
 *         }
 *         container dst {
 *             choice dst-choice {
 *                 case dst-nx-arp-sha-case {
 *                     leaf nx-arp-sha {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-arp-tha-case {
 *                     leaf nx-arp-tha {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-encap-eth-dst-case {
 *                     leaf nx-encap-eth-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-encap-eth-src-case {
 *                     leaf nx-encap-eth-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-ipv6-dst-case {
 *                     leaf nx-ipv6-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-ipv6-src-case {
 *                     leaf nx-ipv6-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-nsh-mdtype-case {
 *                     leaf nx-nsh-mdtype {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-nsh-np-case {
 *                     leaf nx-nsh-np {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-nshc-1-case {
 *                     leaf nx-nshc-1-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-nshc-2-case {
 *                     leaf nx-nshc-2-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-nshc-3-case {
 *                     leaf nx-nshc-3-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-nshc-4-case {
 *                     leaf nx-nshc-4-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-nsi-case {
 *                     leaf nx-nsi-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-nsp-case {
 *                     leaf nx-nsp-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-of-in-port-case {
 *                     leaf of-in-port {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-reg-case {
 *                     leaf nx-reg {
 *                         type identityref;
 *                     }
 *                 }
 *                 case dst-nx-tun-gpe-np-case {
 *                     leaf nx-tun-gpe-np {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-tun-id-case {
 *                     leaf nx-tun-id {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-tun-ipv4-dst-case {
 *                     leaf nx-tun-ipv4-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-tun-ipv4-src-case {
 *                     leaf nx-tun-ipv4-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-arp-op-case {
 *                     leaf of-arp-op {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-arp-spa-case {
 *                     leaf of-arp-spa {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-arp-tpa-case {
 *                     leaf of-arp-tpa {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-eth-dst-case {
 *                     leaf of-eth-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-eth-src-case {
 *                     leaf of-eth-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-icmp-type-case {
 *                     leaf of-icmp-type {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-ip-dst-case {
 *                     leaf of-ip-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-ip-src-case {
 *                     leaf of-ip-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-metadata-case {
 *                     leaf of-metadata {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-mpls-label-case {
 *                     leaf of-mpls-label {
 *                         type empty;
 *                     }
 *                 }
 *             }
 *             leaf start {
 *                 type uint16;
 *             }
 *             leaf end {
 *                 type uint16;
 *             }
 *             uses dst-choice-grouping;
 *             uses range-grouping;
 *         }
 *     }
 * }
 * </pre>
 * The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nx-action-reg-move-grouping</i>
 *
 */
public interface NxActionRegMoveGrouping
    extends
    DataObject
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "nx-action-reg-move-grouping").intern();

    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.move.grouping.NxRegMove</code> <code>nxRegMove</code>, or <code>null</code> if not present
     */
    NxRegMove getNxRegMove();

}

==> openflowplugin-extension-nicira-0.6.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/NxActionRegMoveGrouping.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.move.grouping.NxRegMove;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * grouping nx-action-reg-move-grouping {
 *     container nx-reg-move {
 *         container src {
 *             choice src-choice {
 *                 case src-nx-arp-sha-case {
 *                     leaf nx-arp-sha {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-arp-tha-case {
 *                     leaf nx-arp-tha {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-encap-eth-dst-case {
 *                     leaf nx-encap-eth-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-encap-eth-src-case {
 *                     leaf nx-encap-eth-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-ipv6-dst-case {
 *                     leaf nx-ipv6-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-ipv6-src-case {
 *                     leaf nx-ipv6-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-nsh-mdtype-case {
 *                     leaf nx-nsh-mdtype {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-nsh-np-case {
 *                     leaf nx-nsh-np {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-nshc-1-case {
 *                     leaf nx-nshc-1-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-nshc-2-case {
 *                     leaf nx-nshc-2-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-nshc-3-case {
 *                     leaf nx-nshc-3-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-nshc-4-case {
 *                     leaf nx-nshc-4-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-nsi-case {
 *                     leaf nx-nsi-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-nsp-case {
 *                     leaf nx-nsp-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-of-in-port-case {
 *                     leaf of-in-port {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-of-metadata-case {
 *                     leaf of-metadata {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-of-mpls-label-case {
 *                     leaf of-mpls-label {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-reg-case {
 *                     leaf nx-reg {
 *                         type identityref;
 *                     }
 *                 }
 *                 case src-nx-tun-gpe-np-case {
 *                     leaf nx-tun-gpe-np {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-tun-id-case {
 *                     leaf nx-tun-id {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-tun-ipv4-dst-case {
 *                     leaf nx-tun-ipv4-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-nx-tun-ipv4-src-case {
 *                     leaf nx-tun-ipv4-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-of-arp-op-case {
 *                     leaf of-arp-op {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-of-arp-spa-case {
 *                     leaf of-arp-spa {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-of-arp-tpa-case {
 *                     leaf of-arp-tpa {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-of-eth-dst-case {
 *                     leaf of-eth-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-of-eth-src-case {
 *                     leaf of-eth-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-of-eth-type-case {
 *                     leaf of-eth-type {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-of-ip-dst-case {
 *                     leaf of-ip-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case src-of-ip-src-case {
 *                     leaf of-ip-src {
 *                         type empty;
 *                     }
 *                 }
 *             }
 *             leaf start {
 *                 type uint16;
 *             }
 *             leaf end {
 *                 type uint16;
 *             }
 *             uses src-choice-grouping;
 *             uses range-grouping;
 *         }
 *         container dst {
 *             choice dst-choice {
 *                 case dst-nx-arp-sha-case {
 *                     leaf nx-arp-sha {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-arp-tha-case {
 *                     leaf nx-arp-tha {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-encap-eth-dst-case {
 *                     leaf nx-encap-eth-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-encap-eth-src-case {
 *                     leaf nx-encap-eth-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-ipv6-dst-case {
 *                     leaf nx-ipv6-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-ipv6-src-case {
 *                     leaf nx-ipv6-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-nsh-mdtype-case {
 *                     leaf nx-nsh-mdtype {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-nsh-np-case {
 *                     leaf nx-nsh-np {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-nshc-1-case {
 *                     leaf nx-nshc-1-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-nshc-2-case {
 *                     leaf nx-nshc-2-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-nshc-3-case {
 *                     leaf nx-nshc-3-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-nshc-4-case {
 *                     leaf nx-nshc-4-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-nsi-case {
 *                     leaf nx-nsi-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-nsp-case {
 *                     leaf nx-nsp-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-of-in-port-case {
 *                     leaf of-in-port {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-reg-case {
 *                     leaf nx-reg {
 *                         type identityref;
 *                     }
 *                 }
 *                 case dst-nx-tun-gpe-np-case {
 *                     leaf nx-tun-gpe-np {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-tun-id-case {
 *                     leaf nx-tun-id {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-tun-ipv4-dst-case {
 *                     leaf nx-tun-ipv4-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-nx-tun-ipv4-src-case {
 *                     leaf nx-tun-ipv4-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-arp-op-case {
 *                     leaf of-arp-op {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-arp-spa-case {
 *                     leaf of-arp-spa {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-arp-tpa-case {
 *                     leaf of-arp-tpa {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-eth-dst-case {
 *                     leaf of-eth-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-eth-src-case {
 *                     leaf of-eth-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-icmp-type-case {
 *                     leaf of-icmp-type {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-ip-dst-case {
 *                     leaf of-ip-dst {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-ip-src-case {
 *                     leaf of-ip-src {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-metadata-case {
 *                     leaf of-metadata {
 *                         type empty;
 *                     }
 *                 }
 *                 case dst-of-mpls-label-case {
 *                     leaf of-mpls-label {
 *                         type empty;
 *                     }
 *                 }
 *             }
 *             leaf start {
 *                 type uint16;
 *             }
 *             leaf end {
 *                 type uint16;
 *             }
 *             uses dst-choice-grouping;
 *             uses range-grouping;
 *         }
 *     }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nx-action-reg-move-grouping</i>
 *
 */
public interface NxActionRegMoveGrouping
    extends
    DataObject
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "nx-action-reg-move-grouping").intern();

    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.move.grouping.NxRegMove</code> <code>nxRegMove</code>, or <code>null</code> if not present
     */
    NxRegMove getNxRegMove();

}
